<?php
/*
Plugin Name: Title Colors
Plugin URI: http://trepmal.com/plugins/post-title-colors/
Description: Choose the Title color for posts
Author: Kailey Lampert
Version: 1.1
Author URI: http://kaileylampert.com/
*/
/*
    Copyright (C) 2010-12  Kailey Lampert

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

new titlecolor();
class titlecolor {

	function titlecolor() {
		add_action( 'add_meta_boxes', array( &$this, 'meta_box') );
		add_action( 'admin_enqueue_scripts', array( &$this, 'scripts') );
		add_action( 'save_post', array( &$this, 'update') );
		add_action( 'loop_start', array( &$this, 'front_end_only') );

		//loop_end is a little too late in some places, use backup hooks!
		add_filter( 'get_previous_post_join', array( &$this, 'clean_up') );
		add_filter( 'get_next_post_join', array( &$this, 'clean_up') );
		add_filter( 'loop_end', array( &$this, 'clean_up') );
    }

	function meta_box() {
		add_meta_box('title-color', 'Title Color', array( &$this, 'box'), 'post', 'side');
		// uncomment this line to enable colors on pages
		// add_meta_box('title-color', 'Title Color', array( &$this, 'box'), 'page', 'side');
	}
	
	function box( $post ) { 
		wp_nonce_field( 'a_save', 'n_color' );
		?>
			<input type="text" name="background-color" id="background-color" value="<?php echo get_post_meta( $post->ID,'title_color', true ); ?>" />
			<a class="hide-if-no-js" href="#" id="pickcolor"><?php _e( 'Select a Color', 'post-title-color' ); ?></a>
			<div id="colorPickerDiv" style="z-index: 100; background:#eee; border:1px solid #ccc; position:absolute; display:none;"></div>
		<?php
	}

	function scripts( $hook ) {
		// only load these scripts on the proper admin pages
		$ok = array( 'post.php', 'post-new.php' );
		if ( ! in_array( $hook, $ok ) ) return;

		wp_enqueue_script('jquery');
		wp_enqueue_script('farbtastic');
		wp_enqueue_script('custom-background');
		wp_enqueue_style('farbtastic');
	}	

	function update( $post_id ) {
		if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE )
			return $post_id;

		if ( ! isset( $_POST['post_type'] ) )
			return $post_id;

		if( ! wp_verify_nonce( $_POST['n_color'], 'a_save' ) )
			return $post_id;

		// Check permissions
		if ( 'post' == $_POST['post_type'] ) {
			if ( ! current_user_can( 'edit_post', $post_id ) )
				return $post_id;
		} else {
			if ( ! current_user_can( 'edit_page', $post_id ) )
				return $post_id;
		}

		$color = $_POST['background-color'];

		update_post_meta( $post_id, 'title_color', $color );

		return $color;
	}

	function front_end_only( $query ) {
    	// If we're looping through the main query, apply the title color filter
    	if ( $query->is_main_query() )
   		add_filter( 'the_title', array( &$this, 'add_to_title' ) );
	}

	function add_to_title( $title ) {
		if ( $color = get_post_meta( get_the_ID(), 'title_color', true ) ) {
			return "<span style='color:{$color};'>{$title}</span>";
		}
		return $title;
	}

	function clean_up( $o ) {
		// at the end of the loop, remove the filter so we don't mess up other loops
		remove_filter( 'the_title', array( &$this, 'add_to_title' ) );
		return $o;
	}

}//end class
